# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorarch: %global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

# Some perl versions need special treatment
%global perl_version %(eval "`perl -V:version`"; echo $version)

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'printf "%d\\n", $Test::More::VERSION < 0.88 ? 1 : 0;' 2>/dev/null || echo 0)

# Need to tweak provides filter differently if we have rpm 4.9 onwards
%global rpm49 %(rpm --version | perl -pi -e 's/^.* (\\d+)\\.(\\d+).*/sprintf("%d.%03d",$1,$2) ge 4.009 ? 1 : 0/e')

# TODO: Add BR: perl(DateTime::Format::Ical) when available

Name:		perl-DateTime
Epoch:		2
Version:	0.72
Release:	1.0.cf.%{__distinit}%{__distvers}
Summary:	Date and time objects
License:	Artistic 2.0
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/DateTime/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DR/DROLSKY/DateTime-%{version}.tar.gz
Source10:	perl-module-version-filter
Patch2:		DateTime-0.71-old-Test::More.patch
Patch6:		DateTime-0.68-spelling.patch
Patch7:		DateTime-0.71-Perl580.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# Avoid circular dependencies when bootstrapping
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(DateTime::Format::Strptime)
BuildRequires:	perl(DateTime::Locale) >= 0.41
BuildRequires:	perl(DateTime::TimeZone) >= 1.09
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Math::Round)
BuildRequires:	perl(Module::Build) >= 0.36
BuildRequires:	perl(Params::Validate) >= 0.91
BuildRequires:	perl(Scalar::Util)
# Test::CPAN::Changes requires perl 5.10.x
%if %(perl -e 'print (($] < 5.010000) ? 0 : 1)')
BuildRequires:	perl(Test::CPAN::Changes)
%endif
BuildRequires:	perl(Test::EOL)
%if "%{perl_version}" == "5.8.0"
BuildRequires:	perl(Test::Exception)
%else
BuildRequires:	perl(Test::Fatal)
%endif
BuildRequires:	perl(Test::More) >= 0.34
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Spelling), %(perl -e 'print (($] >= 5.008001) ? "aspell-en" : "aspell-en-gb")')
BuildRequires:	perl(Time::Local) >= 1.04
BuildRequires:	perl(Test::Warn)
Requires:	perl(:MODULE_COMPAT_%{perl_version})
Provides:	perl(DateTimePP) = 0
Provides:	perl(DateTimePPExtra) = 0

# Don't "provide" private Perl libs or unversioned perl(DateTime) (rpm 4.9 onwards)
%global __provides_exclude ^(perl\\(DateTime\\)$|DateTime\\.so)

%description
DateTime is a class for the representation of date/time combinations.  It
represents the Gregorian calendar, extended backwards in time before its
creation (in 1582). This is sometimes known as the "proleptic Gregorian
calendar". In this calendar, the first day of the calendar (the epoch), is the
first day of year 1, which corresponds to the date which was (incorrectly)
believed to be the birth of Jesus Christ.

%prep
%setup -q -n DateTime-%{version}

# Test suite uses feature from Test::More 0.88
%if %{old_test_more}
%patch2 -p1
%endif

# Add extra stopwords to spellchecker test
%patch6 -p2

# The module can actually work with Perl 5.8.0 (and Test::Exception rather than Test::Fatal)
%if "%{perl_version}" == "5.8.0"
%patch7 -p1
%endif

# Auto provides aren't clever enough for what DateTime does, at least prior to Fedora 7
%global __filter_from_prov | PERL5LIB=%{_builddir}/DateTime-%{version}/blib/lib perl -n -s %{SOURCE10}"
%global provfilt /bin/sh -c "%{__perl_provides} %{__filter_from_prov}"
%define __perl_provides %{provfilt}

%build
perl Build.PL installdirs=vendor optimize="%{optflags}"
./Build

%install
rm -rf %{buildroot}
./Build install destdir=%{buildroot} create_packlist=0
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
chmod -R u+w %{buildroot}

%check
LC_ALL=C RELEASE_TESTING=1 ./Build test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc CREDITS Changes LICENSE README TODO
%{_mandir}/man3/DateTime.3pm*
%{_mandir}/man3/DateTime::Duration.3pm*
%{_mandir}/man3/DateTime::Infinite.3pm*
%{_mandir}/man3/DateTime::LeapSecond.3pm*
%{perl_vendorarch}/auto/DateTime/
%{perl_vendorarch}/DateTime/
%{perl_vendorarch}/DateTime.pm
%{perl_vendorarch}/DateTimePP.pm
%{perl_vendorarch}/DateTimePPExtra.pm

%changelog
* Thu Jan  5 2012 Paul Howarth <paul@city-fan.org> 2:0.72-1.0.cf
- Update to 0.72:
  - Remove Test::DependentModules from the dependency list

* Thu Jan  5 2012 Paul Howarth <paul@city-fan.org> 2:0.71-1.0.cf
- Update to 0.71:
  - There will be a new leap second on June 30, 2012
- BR: perl(Test::CPAN::Changes) as the associated test now passes
- Update patch for old Test::More versions
- BR: perl(Test::Fatal) rather than perl(Test::Exception) unless we have
  perl 5.8.0, in which case patch the test suite to use Test::Exception rather
  than Test::Fatal like it used to do

* Fri Aug 19 2011 Paul Howarth <paul@city-fan.org> 2:0.70-1.0.cf
- Unbundle DateTime::TimeZone and DateTime::Locale (#730658)
- Bump epoch and revert to upstream versioning
- Update description
- Update patch for old Test::More versions so that
  DateTime::Format::Strptime is detected properly on old perls

* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> 1:0.7000-3.0.cf
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> 1:0.7000-2.0.cf
- Update DateTime-TimeZone to 1.65:
  - Based on version 2011h of the Olson database
  - Includes changes for Russia
  - Include UTC in the list of all time zone names (CPAN RT#67070)
- Update DateTime-TimeZone patches
- Tweak requires/provides filters for better rpm 4.9 compatibility
- BR: perl(DateTime::Format::Strptime) if we're not bootstrapping
- Add support for perl_bootstrap macro

* Tue May 10 2011 Paul Howarth <paul@city-fan.org> 1:0.7000-1.0.cf
- Update DateTime to 0.70:
  - Really fix %%N, finally; this was breaking the DateTime::Event::Recurrence
    test suite
- Update patches for Perl 5.8.0 and old Test::More versions

* Wed May  4 2011 Paul Howarth <paul@city-fan.org> 1:0.6900-1.0.cf
- Update DateTime to 0.69:
  - When a DateTime object had nanoseconds == 0, the %%N strftime specifier
    always returned "0" regardless of the precision requested (CPAN RT#67928)
- Update patches for Perl 5.8.0 and old Test::More versions

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> 1:0.6800-1.0.cf
- Update DateTime to 0.68:
  - The tests for %%N in the last release relied on the vagaries of floating
    point math on a 64-bit system; now, the from_epoch() method just uses
    string operations to separate the epoch into an integer value and a
    mantissa, which avoids floating point insanity (CPAN RT#67736)
- Update DateTime::TimeZone to 1.34:
  - Based on version 2011g of the Olson database
  - Includes changes for Egypt
  - DateTime::TimeZone::Floating and DateTime::TimeZone::UTC are now
    singletons, since their internal state never changes
- Test::Spelling now available for all releases
- Update spelling patch for DateTime to include words needed for RHL-9/RHEL-3

* Mon Apr 25 2011 Paul Howarth <paul@city-fan.org> 1:0.6700-1.0.cf
- Update DateTime to 0.67:
  - The %%N strftime specifier simply truncated nanoseconds, rather than rounding
    them (CPAN RT#66744)
  - The %%U strftime specifier was off by one in years where January 1st was a
    Sunday (CPAN RT#67631)
  - The %%W strftime specifier was off by one in years where January 1st was a
    Sunday or Monday (CPAN RT#67631)
  - Some small optimizations from Christian Hansen; the biggest impact is for
    calculating week_of_month, week_number and week_year
- BR: perl(Math::Round)
- BuildConflict with perl(Test::CPAN::Changes) as the cpan-changes test fails
- Drop references to Kwalitee tests as upstream has dropped them
- Add patch to drop Perl version requirement to 5.8.0 if necessary
- Run tests against the installed modules in the buildroot rather than the
  uninstalled modules in the build area
- Update patch for building with old Test::More versions

* Mon Apr 11 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-5.0.cf
- Update DateTime::TimeZone to 1.33:
  - Based on version 2011f of the Olson database
  - Changes for the Falkland Islands

* Thu Apr  7 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-4.0.cf
- Rebuild

* Mon Apr  4 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-3.1.cf
- Update DateTime::TimeZone to 1.32:
  - Based on version 2011e of the Olson database
  - Changes for Morocco and Chile

* Mon Mar 28 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-3.0.cf
- Nobody else likes macros for commands
- BuildConflicts with perl(Test::Kwalitee) as the kwalitee test fails

* Mon Mar 21 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-2.5.cf
- Update DateTime::TimeZone to 1.31:
  - Updates for Win32 time zones

* Mon Mar 14 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-2.4.cf
- Update DateTime::TimeZone to 1.30:
  - Based on version 2011d of the Olson database
  - Changes for Samoa, Turkey, and Cuba
- Revert fix for DateTime::Locale::is manpage, which only takes effect on
  releases that didn't generate bogus escapes anyway

* Tue Mar  8 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-2.3.cf
- Update DateTime::TimeZone to 1.29:
  - Based on version 2011b of the Olson database
  - New zones America/Sitka and America/Metlakatla
  - Changes for Alaska and Chile
- Generate DateTime::Locale::is manpage in UTF8 encoding to fix broken
  default transliteration to ASCII, provided we have a recent enough Pod::Man

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-2.2.cf
- Update DateTime::TimeZone to 1.28:
  - Based on version 2011b of the Olson database
  - Includes a new zone, America/North_Dakota/Beulah
- DateTime::TimeZone switched from Build.PL to Makefile.PL
- BR: perl(ExtUtils::MakeMaker)
- Add patch to support building with perl(ExtUtils::MakeMaker) < 6.31

* Tue Jan 25 2011 Paul Howarth <paul@city-fan.org> 1:0.6600-2.1.cf
- Update DateTime::TimeZone to 1.27:
  - Based on version 2011a of the Olson database
  - Includes historical updates for Australia and Hawaii
- Update DateTime::TimeZone patch for spelling check
- Add patch for spelling check for DateTime itself (coverage in Rawhide
  dictionary seems to have gone down)

* Wed Dec 22 2010 Paul Howarth <paul@city-fan.org> 1:0.6600-2.0.cf
- Update URL for FAQ in %%description

* Sat Nov 27 2010 Paul Howarth <paul@city-fan.org> 1:0.6600-1.0.cf
- Update DateTime to 0.66 (documentation changes only)

* Mon Nov 22 2010 Paul Howarth <paul@city-fan.org> 1:0.6500-1.1.cf
- Update DateTime::TimeZone to 1.26:
  - All modules in the distro now have the same $VERSION
  - Based on version 2010n of the Olson database (updates for Fiji)
  - Attempting to determine the local time zone while inside a sort subroutine
    could cause an error "Can't return outside a subroutine", caused by stack
    corruption that happens when an eval "use $module" fails (CPAN RT#63106)
- BR: perl(parent) and perl(Class::Load)
- Update DateTime::TimeZone patch for old Test::more versions
- Add patch for better dictionary coverage in DateTime::TimeZone spelling check

* Tue Oct 26 2010 Paul Howarth <paul@city-fan.org> 1:0.6500-1.0.cf
- Update DateTime to 0.65:
  - All the constructors besides new() ended up calling new(), which meant that
    these constructors went through the parameter validation code twice;
    avoiding this should make everything that constructs a new object (besides
    new() itself) a little faster
  - The t/39no-so.t test failed for some people (CPAN RT#62061)
  - Added a section on the DateTime Project ecosystem to the docs
    (CPAN RT#60930)
  - Fixed wiki links in the docs now that the wiki has moved to a new wiki
    platform
  - Restored some of the dzil-ification; the repo now has a very minimal
    Build.PL file that is just enough to build the XS code and run the tests,
    which fixes the total lack of prereqs in the META.* files (CPAN RT#62427)
- Update DateTime::TimeZone to 1.23:
  - Based on version 2010n of the Olson database
  - Includes updates for Fiji
- Note that Kwalitee test would fail if enabled
- Drop POD patch, no longer needed (DateTime::Helpers manpage no longer
  generated as a result)
- Update DateTime patch for old Test::More versions

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> 1:0.6300-1.2.cf
- Rebuild for gcc bug (#634757)

* Tue Sep 28 2010 Paul Howarth <paul@city-fan.org> 1:0.6300-1.1.cf
- Update DateTime::TimeZone to 1.22
  - Based on version 2010m of the Olson database
  - Includes historical updates for Hong Kong

* Mon Sep 27 2010 Paul Howarth <paul@city-fan.org> 1:0.6300-1.0.cf
- Update DateTime to 0.63 (actually bump the version in the module files)

* Fri Sep 24 2010 Paul Howarth <paul@city-fan.org> 1:0.6200-1.0.cf
- Update DateTime to 0.62 (don't try to test with
  DateTime::Format::Strptime unless we have a relatively recent version)
- Update patches for POD, UTF-8, perl 5.8.8 and old Test::More versions

* Fri Aug 20 2010 Paul Howarth <paul@city-fan.org> 1:0.6100-1.2.cf
- Update DateTime::TimeZone to 1.21
  - Based on version 2010l of the Olson database
  - Updates for Egypt and Palestine

* Tue Jul 27 2010 Paul Howarth <paul@city-fan.org> 1:0.6100-1.1.cf
- Update DateTime::TimeZone to 1.20
  - Based on version 2010k of the Olson database
  - Updates for Egypt, Finland (historical only), and Mexico
  - Rename Pacific/Truk to Pacific/Chuuk and Pacific/Ponape to Pacific/Pohnpei

* Mon Jul 19 2010 Paul Howarth <paul@city-fan.org> 1:0.6100-1.0.cf
- Update DateTime to 0.61
  - Fix the --pp flag for the Build.PL (CPAN RT#59421)
- Drop upstreamed spelling test patches

* Mon Jul  5 2010 Paul Howarth <paul@city-fan.org> 1:0.6000-1.0.cf
- Update DateTime to 0.60 (by default, Dist::Zilla generates a Build.PL that
  requires Module::Build 0.3601+, but this distro really doesn't need any
  particular version)

* Wed Jun 30 2010 Paul Howarth <paul@city-fan.org> 1:0.5900-1.0.cf
- Update DateTime to 0.59 (make sure that POD only shows up in the right files;
  in 0.56 through 0.58, some POD in the wrong place confused the
  search.cpan.org POD display code, and the main module's documentation wasn't
  viewable)
- Update patch for old Test::More versions due to renaming of test files and
  addition of pure-perl release tests

* Tue Jun 29 2010 Paul Howarth <paul@city-fan.org> 1:0.5800-1.0.cf
- Update DateTime to 0.58
  - Make DateTime::LeapSecond have the same $VERSION as every other .pm file
  - The set_formatter() method did not return the DateTime object, and did not
  actually validate the value provided for the formatter (CPAN RT#58506)
  - Improved docs on floating time zone (CPAN RT#56389)
  - Mention of end-of-month algorithms to docs on DateTime math (CPAN RT#58533)
  - License is now Artistic 2.0
- Main package now Artistic 2.0
- Drop UTF8 patch for DateTime, no longer needed
- Buildreq Test::NoTabs, Test::EOL, Test::Spelling and aspell-en
- Enable RELEASE_TESTING
- Add patch for additional words for the spell checker to ignore
- Update patch for old Test::More versions
- Use our own perl provides script as the default one prior to Fedora 7
  isn't clever enough to parse the code

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-2.1.cf
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-2.0.cf
- RHEL-6 onwards have noarch subpackages, so use them

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.7.cf
- Update DateTime::TimeZone to 1.19
  - This release is based on version 2010j of the Olson database
  - Create a new zone for Mexico (America/Bahia_Banderas)
  - Dateline time zone on Win32 now always maps to a fixed -12:00 zone
- Add patch for Test::More < 0.88 in DateTime::TimeZone
- Fix dist tag for RHEL-6 Beta

* Tue Apr 20 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.6.cf
- Update DateTime::TimeZone to 1.18
  - This release is based on version 2010i of the Olson database
  - Changes for Morocco, Taiwan (historical only), and Argentina

* Mon Apr 12 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.5.cf
- Update DateTime::TimeZone to 1.17
  - Updated Win32 to Olson name translation mapping (CPAN RT#56445)

* Tue Apr  6 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.4.cf
- Update DateTime::TimeZone to 1.16
  - Based on version 2010h (changes for Tunisia and Pakistan)

* Tue Mar 30 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.3.cf
- Update DateTime::TimeZone to 1.15
  - Based on version 2010g (changes for Bangladesh, Palestine, and Russia)

* Tue Mar 23 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.2.cf
- Update DateTime::TimeZone to 1.14
  - Based on version 2010f (changes for Antartica, Syria, and Samoa)

* Sat Mar 20 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.1.cf
- Update DateTime::Locale to 0.45
  - Drop dependency on Class::ISA (CPAN RT#53940)
  - All methods deprecated in the last release now warn when called
  - Add methods to return per-locale strftime formats from the glibc data
- Drop perl(Class::ISA) buildreq

* Tue Mar 16 2010 Paul Howarth <paul@city-fan.org> 1:0.5500-1.0.cf
- Update DateTime to 0.55 (get all tests passing on 5.6.2)
- Drop DateTime patch for perl 5.8.0, issue fixed upstream

* Sun Mar 14 2010 Paul Howarth <paul@city-fan.org> 1:0.5400-1.0.cf
- Update DateTime to 0.54
  - String overloading now extends to string comparison (CPAN RT#55453)
  - Allow passing end_of_month setting to $duration->inverse() (CPAN RT#53985)
- Update UTF8 patch
- New DateTime patch for old Test::More versions, with patch for old
  Scalar::Util merged into it
- Add patch to fix DateTime on perl 5.8.0 if necessary
- Split DT::Locale and DT::TimeZone into their own subpackages but enforce
  strict dependencies to make sure that all packages are pulled in together as
  if the bundling was still there; this makes it easier for users to find the
  DT::Locale and DT::TimeZone packages without breaking things
- Add a repotag to avoid confusion with Fedora build

* Mon Mar  8 2010 Paul Howarth <paul@city-fan.org> 1:0.5300-5
- Update DateTime::TimeZone to 1.13
  - Based on version 2010e (changes for Bangladesh, Fiji, Samoa, and Chile)

* Tue Mar  2 2010 Paul Howarth <paul@city-fan.org> 1:0.5300-4
- Update DateTime::TimeZone to 1.11
  - Based on version 2010b of the Olson database (changes for Paraguay)
  - Added a list of zones by country
  - Added a list of zone links (aliases) to DateTime::TimeZone::Catalog docs
- Remove redundant call of %%{?filter_setup}

* Tue Jan 26 2010 Paul Howarth <paul@city-fan.org> 1:0.5300-3
- Update DateTime::TimeZone to 1.10 (changes for Mexico)
- Fix up patch applications to work with newer versions of modules

* Fri Jan 22 2010 Paul Howarth <paul@city-fan.org> 1:0.5300-2
- Import from Fedora
- Update DateTime::TimeZone to 1.09
- Use patch to recode to utf-8, not iconv
- Filter unwanted requires/provides in a way that works on old distributions
- Skip no-so test if we don't have Scalar::Util >= 1.10
- Skip DateTime::TimeZone error test in 5.8.8

* Fri Jan 15 2010 Stepan Kasal <skasal@redhat.com> 1:0.5300-1
- New upstream version
- Use Build.PL as Makefile.PL no longer exists
- Use iconv to recode to utf-8, not a patch
- Update BuildRequires
- Drop Provides: perl(DateTime::TimeZoneCatalog), it is no longer there
- Use filtering macros

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> 1:0.4501-4
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1:0.4501-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1:0.4501-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Dec 09 2008 Steven Pritchard <steve@kspei.com> 1:0.4501-1
- Update to DateTime 0.4501

* Mon Nov 10 2008 Steven Pritchard <steve@kspei.com> 1:0.4401-1
- Update to DateTime 0.4401
- Update to DateTime::Locale 0.42
- Update to DateTime::TimeZone 0.8301

* Mon Sep 08 2008 Steven Pritchard <steve@kspei.com> 1:0.4304-2
- Update to DateTime::TimeZone 0.7904

* Tue Jul 15 2008 Steven Pritchard <steve@kspei.com> 1:0.4304-1
- Update to DateTime 0.4304
- Update to DateTime::TimeZone 0.78
- Update to DateTime::Locale 0.41

* Tue Jul 08 2008 Steven Pritchard <steve@kspei.com> 1:0.4302-2
- Update to DateTime::TimeZone 0.7701

* Sat May 31 2008 Steven Pritchard <steve@kspei.com> 1:0.4302-1
- Update to DateTime 0.4302
- Update to DateTime::TimeZone 0.77
- Update to DateTime::Locale 0.4001
- BR List::MoreUtils
- Define IS_MAINTAINER so we run the pod tests

* Thu May 15 2008 Steven Pritchard <steve@kspei.com> 1:0.42-1
- Update to DateTime 0.42
- Update to DateTime::TimeZone 0.75
- Update FAQ URL in description

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1:0.41-5
- Rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> 1:0.41-4
- Autorebuild for GCC 4.3

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1:0.41-3
- Rebuild for new perl

* Tue Dec 11 2007 Steven Pritchard <steve@kspei.com> 1:0.41-2
- Update License tag
- Update to DateTime::TimeZone 0.70

* Mon Sep 17 2007 Steven Pritchard <steve@kspei.com> 1:0.41-1
- Update to DateTime 0.41
- Update to DateTime::Locale 0.35
- Update to DateTime::TimeZone 0.67

* Wed Aug 29 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> 1:0.39-2
- Rebuild for selinux ppc32 issue

* Sun Jul 22 2007 Steven Pritchard <steve@kspei.com> 1:0.39-1
- Update to DateTime 0.39
- Update to DateTime::TimeZone 0.6603

* Thu Jul 05 2007 Steven Pritchard <steve@kspei.com> 1:0.38-2
- BR Test::Output

* Mon Jul 02 2007 Steven Pritchard <steve@kspei.com> 1:0.38-1
- Update to DateTime 0.38
- Update to DateTime::TimeZone 0.6602
- BR Test::Pod::Coverage

* Mon Apr 02 2007 Steven Pritchard <steve@kspei.com> 1:0.37-3
- Drop BR DateTime::Format::* to avoid circular build deps

* Mon Apr 02 2007 Steven Pritchard <steve@kspei.com> 1:0.37-2
- Filter Win32::TieRegistry dependency
- Do the provides filter like we do in cpanspec
- Drop some macro usage

* Sat Mar 31 2007 Steven Pritchard <steve@kspei.com> 1:0.37-1
- Update to DateTime 0.37
- Update to DateTime::TimeZone 0.63

* Tue Mar 13 2007 Steven Pritchard <steve@kspei.com> 1:0.36-2
- Update to DateTime::Locale 0.34
- Update to DateTime::TimeZone 0.62

* Mon Jan 22 2007 Steven Pritchard <steve@kspei.com> 1:0.36-1
- Update to Date::Time 0.36
- Update to DateTime::Locale 0.33
- Update to DateTime::TimeZone 0.59

* Fri Nov 03 2006 Steven Pritchard <steve@kspei.com> 1:0.35-1
- Update to DateTime 0.35
- Update to DateTime::Locale 0.3101
- LICENSE.icu seems to have been renamed LICENSE.cldr
- Update to DateTime::TimeZone 0.54
- Use fixperms macro instead of our own chmod incantation
- Convert DateTime::LeapSecond to UTF-8 to avoid a rpmlint warning

* Tue Aug 29 2006 Steven Pritchard <steve@kspei.com> 1:0.34-3
- Update to DateTime::TimeZone 0.48

* Mon Aug 28 2006 Steven Pritchard <steve@kspei.com> 1:0.34-2
- Update to DateTime::TimeZone 0.47

* Mon Aug 14 2006 Steven Pritchard <steve@kspei.com> 1:0.34-1
- Update to DateTime 0.34

* Fri Jul 28 2006 Steven Pritchard <steve@kspei.com> 1:0.32-1
- Update to DateTime 0.32
- Improve Summary, description, and source URLs
- Fix find option order

* Thu Jul 13 2006 Steven Pritchard <steve@kspei.com> 1:0.31-2
- BR DateTime::Format::ICal and DateTime::Format::Strptime for better
  test coverage

* Wed May 24 2006 Steven Pritchard <steve@kspei.com> 1:0.31-1
- Update DateTime to 0.31
- Update DateTime::TimeZone to 0.46

* Mon Feb 27 2006 Steven Pritchard <steve@kspei.com> 1:0.30-3
- Bump Epoch (argh, 0.2901 > 0.30 to rpm)
- Update DateTime::TimeZone to 0.42

* Sat Feb 18 2006 Steven Pritchard <steve@kspei.com> 0.30-2
- Update DateTime::TimeZone to 0.41

* Tue Jan 10 2006 Steven Pritchard <steve@kspei.com> 0.30-1
- Update DateTime to 0.30
- Update DateTime::TimeZone to 0.40

* Fri Sep 16 2005 Paul Howarth <paul@city-fan.org> 0.2901-2
- Unpack each tarball only once
- Use Module::Build's build script where available
- Help each module find the others when needed
- Clean up files list
- Include additional documentation from DT::Locale & DT::TimeZone
- Add BR: perl(File::Find::Rule) & perl(Test::Pod) to improve test coverage
- Remove unversioned provides of perl(DateTime) & perl(DateTime::TimeZone)

* Wed Aug 31 2005 Steven Pritchard <steve@kspei.com> 0.2901-1
- Specfile autogenerated
